@@ -5,7 +5,7 @@ use parent 'App::githook::perltidy';
 use File::Basename;
 use Path::Tiny;
 
-our $VERSION = '0.11.11_4';
+our $VERSION = '0.12.0';
 
 sub run {
     my $self = shift;
@@ -38,7 +38,7 @@ App::githook::perltidy::install - install git hooks
 
 =head1 VERSION
 
-0.11.11_4 (2018-07-31)
+0.12.0 (2018-08-02)
 
 =head1 SEE ALSO
 
