@@ -3,7 +3,7 @@ use strict;
 use warnings;
 use parent 'App::githook::perltidy';
 
-our $VERSION = '0.11.11_4';
+our $VERSION = '0.12.0';
 
 sub run {
 
@@ -19,7 +19,7 @@ App::githook::perltidy::post_commit - git post-commit hook
 
 =head1 VERSION
 
-0.11.11_4 (2018-07-31)
+0.12.0 (2018-08-02)
 
 =head1 DESCRIPTION
 
